Struct oro_common::BuildManifest
source · pub struct BuildManifest {
pub bin: HashMap<String, PathBuf>,
pub scripts: HashMap<String, String>,
}Expand description
Manifest intended for use with the build step in orogene’s installer. It
reads and normalizes a package.json’s bins (including the
directories.bin field), and its scripts object.
Fields
bin: HashMap<String, PathBuf>Mapping of bin name to the relative path to the script/binary.
scripts: HashMap<String, String>package.json scripts object.
Implementations
sourceimpl BuildManifest
impl BuildManifest
sourcepub fn from_path(path: impl AsRef<Path>) -> Result<Self>
pub fn from_path(path: impl AsRef<Path>) -> Result<Self>
Create a new BuildManifest from a given path to a full manifest (package.json),
normalizing its bin field (or its directories.bin) into a plain HashMap.
sourcepub fn from_manifest(manifest: &Manifest) -> Result<Self>
pub fn from_manifest(manifest: &Manifest) -> Result<Self>
Create a new BuildManifest from an already fully loaded Manifest,
normalizing its bin field (or its directories.bin) into a plain HashMap.