Struct oro_common::Manifest
source · pub struct Manifest {Show 32 fields
pub name: Option<String>,
pub version: Option<Version>,
pub description: Option<String>,
pub homepage: Option<String>,
pub license: Option<String>,
pub bugs: Option<Bugs>,
pub keywords: Vec<String>,
pub bin: Option<Bin>,
pub author: Option<PersonField>,
pub contributors: Vec<PersonField>,
pub files: Option<Vec<String>>,
pub main: Option<String>,
pub man: Option<Man>,
pub directories: Option<Directories>,
pub module_type: Option<String>,
pub exports: Option<Exports>,
pub imports: Option<Imports>,
pub repository: Option<Repository>,
pub scripts: HashMap<String, String>,
pub config: Option<Value>,
pub engines: HashMap<String, Range>,
pub os: Vec<String>,
pub cpu: Vec<String>,
pub private: Option<bool>,
pub publish_config: HashMap<String, Value>,
pub dependencies: BTreeMap<String, String>,
pub dev_dependencies: BTreeMap<String, String>,
pub optional_dependencies: BTreeMap<String, String>,
pub peer_dependencies: BTreeMap<String, String>,
pub bundled_dependencies: Vec<String>,
pub workspaces: Vec<String>,
pub _rest: HashMap<String, Value>,
}Fields
name: Option<String>The name of the package.
If this is missing, it usually indicates that this package exists only to describe a workspace, similar to Cargo’s notion of a “virtual manifest”.
version: Option<Version>The version of the package.
Package managers generally require this to be populated to actually publish the package, but will tolerate its absence during local development.
description: Option<String>homepage: Option<String>license: Option<String>bugs: Option<Bugs>keywords: Vec<String>bin: Option<Bin>Information about the names and locations of binaries this package provides.
Use crate::BuildManifest::from_manifest to get a normalized version
of this field (and other related fields).
contributors: Vec<PersonField>files: Option<Vec<String>>main: Option<String>man: Option<Man>directories: Option<Directories>module_type: Option<String>exports: Option<Exports>imports: Option<Imports>repository: Option<Repository>Information about the repository this project is hosted in.
Repository::Str can contain many different formats (or plain garbage),
we recommend trying to .parse() it as oro-package-spec’s GitInfo type,
as it understands most of the relevant formats.
scripts: HashMap<String, String>Information about build scripts the package uses.
Use crate::BuildManifest::from_manifest to get a normalized version
of this field (and other related fields).
config: Option<Value>engines: HashMap<String, Range>os: Vec<String>cpu: Vec<String>private: Option<bool>publish_config: HashMap<String, Value>dependencies: BTreeMap<String, String>dev_dependencies: BTreeMap<String, String>optional_dependencies: BTreeMap<String, String>peer_dependencies: BTreeMap<String, String>bundled_dependencies: Vec<String>workspaces: Vec<String>_rest: HashMap<String, Value>